from __future__ import print_function
import xml.etree.ElementTree as ET

def getNumberViaURL(name):
    import urllib
    import requests
    url = 'http://cicsphone.apps.elpaas.com:8080/onldemops/servlet?transid=ONLR'
    # Prepare the data
    values = {'DFH_CURSOR': "NAME",
                'NAME': name,
            'PHONE' : "_" ,
            'MESSB' : "",
            'DFH_PF5' : "PF5"
                }
    data = urllib.urlencode(values)

    r = requests.get(url)
    jar = r.cookies
    jarsession =  jar['JSESSIONID']
    cooks={'JSESSIONID': jarsession}
    headers = {"Content-Type": "application/x-www-form-urlencoded; charset=UTF-8"}
    r = requests.post(url, data=data,cookies=cooks,headers=headers)
    if r.status_code != 200:
        return "Unavailable at this time"
    index= r.text.find('<pre id="MESS" class="line18 col23 defaultfg brt len40">')
    if index == -1:
        return "Not found"
    strings=r.text.split('<pre id="MESS" class="line18 col23 defaultfg brt len40">')
    number = strings[1].split("</pre>")[0]
    return number





# --------------- Helpers that build all of the responses ----------------------

def build_speechlet_response(title, output, reprompt_text, should_end_session):
    return {
        'outputSpeech': {
            'type': 'PlainText',
            'text': output
        },
        'card': {
            'type': 'Simple',
            'title': "Heirloom CICS Number App" ,
            'content':  output
        },
        'reprompt': {
            'outputSpeech': {
                'type': 'PlainText',
                'text': reprompt_text
            }
        },
        'shouldEndSession': should_end_session
    }


def build_response(session_attributes, speechlet_response):
    return {
        'version': '1.0',
        'sessionAttributes': session_attributes,
        'response': speechlet_response
    }


# --------------- Functions that control the skill's behavior ------------------

def get_welcome_response():
   
    session_attributes = {}
    card_title = "Welcome"
    speech_output = "Welcome to the Heirloom C I CS Alexa interface. You can ask for someones number by saying; what is the number for, and then the persons name."
    reprompt_text = "Please ask for someones number like this: what is the number for Dave?"
    should_end_session = False
    return build_response(session_attributes, build_speechlet_response(
        card_title, speech_output, reprompt_text, should_end_session))
        
def get_confused_response():
    session_attributes = {}
    card_title = "I didnt understand you"
    speech_output = "Sorry, I didn't understand you. You can ask for someones number by saying; what is the number for, and then the persons name."
    reprompt_text = "Please ask for someones number like this: what is the number for Dave?"
    should_end_session = False
    return build_response(session_attributes, build_speechlet_response(
        card_title, speech_output, reprompt_text, should_end_session))


def handle_session_end_request():
    card_title = "Session Ended"
    speech_output = "Thank you for trying the Heirloom C I CS Alexa interface"
    should_end_session = True
    return build_response({}, build_speechlet_response(
        card_title, speech_output, None, should_end_session))



def askfornumber(intent, session):
    session_attributes = {}
    reprompt_text = None
    person = 'not known'
    if 'person' in intent['slots'] and 'value' in intent['slots']['person']:
        person = intent['slots']['person']['value']
    else:
        return get_welcome_response()
        
    speech_output = "The number for " + person +" is "
    speech_output+= getNumberViaURL(person)
    print(person)
    should_end_session = True

    return build_response(session_attributes, build_speechlet_response(
        intent['name'], speech_output, reprompt_text, should_end_session))


# --------------- Events ------------------

def on_session_started(session_started_request, session):
    pass

def on_launch(launch_request, session):
    return get_welcome_response()


def on_intent(intent_request, session):
    intent = intent_request['intent']
    intent_name = intent_request['intent']['name']

    if intent_name == "asknumber":
        return askfornumber(intent, session)
    else:
        raise ValueError("Invalid intent")


def on_session_ended(session_ended_request, session):
    pass


# --------------- Main handler ------------------

def lambda_handler(event, context):
    
    if event['session']['new']:
        on_session_started({'requestId': event['request']['requestId']},
                           event['session'])

    if event['request']['type'] == "LaunchRequest":
        return on_launch(event['request'], event['session'])
    elif event['request']['type'] == "IntentRequest":
        return on_intent(event['request'], event['session'])
    elif event['request']['type'] == "SessionEndedRequest":
        return on_session_ended(event['request'], event['session'])

